<?

 /*************************************************************************************
 * Filename: modules/pluginConfigs.php
 *
 * This file is part of the ITS JAS plugin.
 * Copyright 2003-2015 by Matthijs Schuurman
 *
 * The ITS JAS plugin is free software under the terms of the
 * GNU General Public License version 3 or any later version.
 *
 * For information about the license please refer to:
 * LICENSE.txt in the root of the plugin or http://jas.junerules.com/plugins/its/
 *************************************************************************************/


 require_once($_path["include"]."module.php");

 class Plugin_Module_its_pluginConfigs extends Module
 {
  function __construct(&$data)
  {
   parent::__construct($data);

   if($this->data->module!="pluginConfigs")
    $this->extend("pluginConfigs");

   $this->data->title="ITS plugin configuration";

   $this->data->addField("listtype", "enum", "all", "reload", false, false, "ITS", "Show");
   $this->data->enumOptions("listtype", "ITS", "Email", "Latest issues", "Latest updates", "Tag cloud");

   $this->data->addField("listcatnr", "nr", "all", "", false, false, 0, "List category");
   $this->data->addReference("listcatnr", "categories", "nr", "*:0");

   $this->data->addField("itspage", "boolean", "all", "reload", false, false, false, "Use ITS page");
   $this->data->addField("itspagenr", "nr", "all", "", false, false, false, "ITS page");
   $this->data->addReference("itspagenr", "categories", "nr", "*:0");

   $this->data->addField("cmspage", "boolean", "all", "reload", false, false, false, "Use CMS page");
   $this->data->addField("cmspagenr", "nr", "all", "", false, false, false, "CMS page");
   $this->data->addReference("cmspagenr", "categories", "nr", "*:0");

   $this->data->addField("pagebrowser", "boolean", "all", "reload", false, false, false, "Show page browser");
   $this->data->addField("listitems", "nr", "all", "", 0, 100, 10, "Number of its issues");
   $this->data->addField("templatepagebrowser", "localfile", "all", "recursive", false, 255, "", "Alternative page browser template");

   $this->data->addField("templateitem", "localfile", "all", "recursive", false, 255, "", "Item template");
   $this->data->addField("templatelist", "localfile", "all", "recursive", false, 255, "", "List template");

   $this->data->group("Show", "listtype", "listcatnr", "itspage", "itspagenr", "cmspage", "cmspagenr");
   $this->data->group("Page browser", "pagebrowser", "listitems", "templatepagebrowser");
   $this->data->group("Alternative templates", "templateitem", "templatelist");
  }

  function postInit()
  {
   global $_path;

   $this->data->setFileDir("templatepagebrowser", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templatepagebrowser", "html", "htm");
   $this->data->setFileDir("templateitem", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templateitem", "html", "htm");
   $this->data->setFileDir("templatelist", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templatelist", "html", "htm");

   return $this->customizeFields();
  }
  function copyPostGet(){return $this->customizeFields();}
  function editPostGet(){return $this->customizeFields();}
  function movePostGet(){return $this->customizeFields();}
  function deletePostGet(){return $this->customizeFields();}

  function customizeFields()
  {
   global $_config;

   $this->data->resetField("itspage");

   if($this->data->getValue("itspage"))
    $this->data->resetField("itspagenr");
   else
    $this->data->field["itspagenr"]["properties"].=";hidden";


   if($this->data->getValue("listtype")=="ITS")
   {
    $this->data->resetField("listcatnr");

    $this->data->resetField("cmspage");

    if($this->data->getValue("cmspage"))
     $this->data->resetField("cmspagenr");
    else
     $this->data->field["cmspagenr"]["properties"].=";hidden";

    $this->data->resetField("listitems");

    $this->data->resetField("pagebrowser");

    if(!$this->data->getValue("pagebrowser"))
    {
     $this->data->field["templatepagebrowser"]["properties"].=";hidden";

     //move listitems to List group
     $this->data->field["listitems"]["min"]=0;
     $this->data->field["listitems"]["defaultvalue"]=0;
     $this->data->field["listitems"]["group"]=$this->data->getGroupID("Show");

     $this->data->field["listitems"]["title"]="Number of its issues";
    }
    else
    {
     $this->data->resetField("templatepagebrowser");

     $this->data->resetField("listitems");
     $this->data->field["listitems"]["group"]=$this->data->getGroupID("Page browser");
     $this->data->field["listitems"]["title"]="Items per page";
    }

    $this->data->resetField("templateitem");
    $this->data->resetField("templatelist");
    $this->data->field["templatelist"]["title"]="List template";
   }
   else if($this->data->getValue("listtype")=="Email")
   {
    $this->data->e->add("The Email configuration allows you to automatically send add/update emails to subscribers", "note");

    $this->data->field["listcatnr"]["properties"].=";hidden";

    //force key to ensure only 1 Email configuration is added and issues modules sendEail can find it
    $this->data->setValue("key", "Email");
    $this->data->field["key"]["properties"].=";disabled";

    //force item page
    $this->data->resetField("itspage");
    $this->data->setValue("itspage", true);
    $this->data->field["itspage"]["properties"].=";disabled";

    $this->data->resetField("itspagenr");

    $this->data->field["cmspage"]["properties"].=";hidden";
    $this->data->field["cmspagenr"]["properties"].=";hidden";

    $this->data->field["listitems"]["properties"].=";hidden";
    $this->data->field["listitems"]["min"]=0;

    $this->data->field["pagebrowser"]["properties"].=";hidden";
    $this->data->field["templatepagebrowser"]["properties"].=";hidden";

    $this->data->resetField("templateitem");
    $this->data->field["templatelist"]["properties"].=";hidden";

    //check usermodule for email fields
    $d=Data::cache($_config->get("usermodule"));
    if(!$d->check("type", "email"))
    {
     $this->data->e->add("User module (".$_config->get("usermodule").") doesn't contain any email fields", "error");
     return false;
    }
   }
   else if($this->data->getValue("listtype")=="Latest issues"||$this->data->getValue("listtype")=="Latest updates")
   {
    $this->data->resetField("listcatnr");

    $this->data->field["cmspage"]["properties"].=";hidden";
    $this->data->field["cmspagenr"]["properties"].=";hidden";

    $this->data->resetField("listitems");

    //move listitems to List group
    $this->data->field["listitems"]["min"]=1;
    $this->data->field["listitems"]["defaultvalue"]=5;
    $this->data->field["listitems"]["group"]=$this->data->getGroupID("Show");

    if($this->data->getValue("listtype")=="Latest issues")
     $this->data->field["listitems"]["title"]="Number of its issues";
    else //Latest updates
     $this->data->field["listitems"]["title"]="Number of updates";

    $this->data->field["pagebrowser"]["properties"].=";hidden";
    $this->data->field["templatepagebrowser"]["properties"].=";hidden";

    $this->data->field["templateitem"]["properties"].=";hidden";

    $this->data->resetField("templatelist");
    $this->data->field["templatelist"]["title"]="Latest template";
   }
   else //tags cloud
   {
    $this->data->resetField("listcatnr");

    $this->data->field["cmspage"]["properties"].=";hidden";
    $this->data->field["cmspagenr"]["properties"].=";hidden";

    $this->data->field["listitems"]["properties"].=";hidden";

    $this->data->field["pagebrowser"]["properties"].=";hidden";
    $this->data->field["templatepagebrowser"]["properties"].=";hidden";

    $this->data->field["templateitem"]["properties"].=";hidden";

    $this->data->resetField("templatelist");
    $this->data->field["templatelist"]["title"]="Cloud template";
   }

   return true;
  }

 }
?>
